@@ -8,7 +8,7 @@ mod images;
 
 use std::io::Write;
 use std::sync::Arc;
-use streamduck_client::daemon::socket::daemon_data::{DoButtonActionResult, GetButtonResult, GetDeviceResult, PopScreenResult, SetBrightnessResult, SetButtonResult};
+use streamduck_client::daemon::daemon_data::{DoButtonActionResult, GetButtonResult, GetDeviceResult, PopScreenResult, SetBrightnessResult, SetButtonResult};
 use streamduck_client::SDClient;
 use streamduck_core::core::button::Button;
 use crate::prompt::buttons::{button_component, button_from, button_new, button_remove};
